@@ -9,10 +9,6 @@
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
-#
-import os
-import sys
-sys.path.insert(0, os.path.abspath('..'))
 
 import sphinx_rtd_theme
 
@@ -24,7 +20,7 @@ copyright = '2016, MS List'
 author = 'MS List'
 
 # The full version, including alpha/beta/rc tags
-release = '1.3.0'
+release = '1.4.1'
 
 
 # -- General configuration ---------------------------------------------------
@@ -73,4 +69,4 @@ html_theme = 'sphinx_rtd_theme'
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
\ No newline at end of file
+html_static_path = ['_static']
