@@ -15,15 +15,15 @@ All instances of the classes in this module should be treated as read
 only. No attributes should be changed once they're created.
 """
 
+import abc
 from datetime import date
 from numbers import Number
-from functools import lru_cache
 
 from pyluach import utils
 from pyluach import gematria
 
 
-class BaseDate:
+class BaseDate(abc.ABC):
     """BaseDate is a base class for all date types.
 
     It provides the following arithmetic and comparison operators
@@ -48,71 +48,105 @@ class BaseDate:
     diffed with any other valid date type.
     """
 
+    _error_string = 'An error has occured.'
+
+    @property
+    @abc.abstractmethod
+    def jd(self):
+        """Return julian day number."""
+
     def __hash__(self):
         return hash(self.jd)
 
     def __add__(self, other):
         try:
             return JulianDay(self.jd + other)._to_x(self)
-        except TypeError:
-            raise TypeError('You can only add a number to a date.')
+        except TypeError as e:
+            raise TypeError('You can only add a number to a date.') from e
 
     def __sub__(self, other):
         try:
             if isinstance(other, Number):
                 return JulianDay(self.jd - other)._to_x(self)
             return abs(self.jd - other.jd)
-        except (AttributeError, TypeError):
-            raise TypeError("""You can only subtract a number or another date
-                              that has a "jd" attribute from a date""")
+        except (AttributeError, TypeError) as e:
+            raise TypeError(
+                'You can only subtract a number or another date'
+                'that has a "jd" attribute from a date'
+            ) from e
 
     def __eq__(self, other):
         try:
             if self.jd == other.jd:
                 return True
             return False
-        except AttributeError:
-            raise TypeError(self._error_string)
+        except AttributeError as e:
+            raise TypeError(self._error_string) from e
 
     def __ne__(self, other):
         try:
             if self.jd != other.jd:
                 return True
             return False
-        except AttributeError:
-            raise TypeError(self._error_string)
+        except AttributeError as e:
+            raise TypeError(self._error_string) from e
 
     def __lt__(self, other):
         try:
             if self.jd < other.jd:
                 return True
             return False
-        except AttributeError:
-            raise TypeError(self._error_string)
+        except AttributeError as e:
+            raise TypeError(self._error_string) from e
 
     def __gt__(self, other):
         try:
             if self.jd > other.jd:
                 return True
             return False
-        except AttributeError:
-            raise TypeError(self._error_string)
+        except AttributeError as e:
+            raise TypeError(self._error_string) from e
 
     def __le__(self, other):
         try:
             if self.jd <= other.jd:
                 return True
             return False
-        except AttributeError:
-            raise TypeError(self._error_string)
+        except AttributeError as e:
+            raise TypeError(self._error_string) from e
 
     def __ge__(self, other):
         try:
             if self.jd >= other.jd:
                 return True
             return False
-        except AttributeError:
-            raise TypeError(self._error_string)
+        except AttributeError as e:
+            raise TypeError(self._error_string) from e
+
+    def weekday(self):
+        """Return day of week as an integer.
+
+        Returns
+        -------
+        int
+            An integer representing the day of the week with Sunday as 1
+            through Saturday as 7.
+        """
+        return int(self.jd+.5+1) % 7 + 1
+
+    def isoweekday(self):
+        """Return the day of the week corresponding to the iso standard.
+
+        Returns
+        -------
+        int
+            An integer representing the day of the week where Monday
+            is 1 and and Sunday is 7.
+        """
+        weekday = self.weekday()
+        if weekday == 1:
+            return 7
+        return weekday - 1
 
     def shabbos(self):
         """Return the Shabbos on or following the date.
@@ -122,7 +156,7 @@ class BaseDate:
         ``HebrewDate``, ``GregorianDate``, or ``JulianDay``
             `self` if the date is Shabbos or else the following Shabbos as
             the same date type as operated on.
-        
+
         Examples
         --------
         >>> heb_date = HebrewDate(5781, 3, 29)
@@ -151,7 +185,7 @@ class BaseDate:
         """
         return utils._fast_day_string(self, hebrew)
 
-    def festival(self, israel=False, hebrew=False):
+    def festival(self, israel=False, hebrew=False, include_working_days=True):
         """Return name of Jewish festival of date.
 
         This method will return all major and minor religous
@@ -165,6 +199,10 @@ class BaseDate:
         hebrew : bool, optional
             ``True`` if you want the festival name in Hebrew letters. Default
             is ``False``, which returns the name transliterated into English.
+        include_working_days : bool, optional
+            ``True`` to include festival days on which melacha (work) is
+            allowed; ie. Pesach Sheni, Chol Hamoed, etc.
+            Default is ``True``.
 
         Returns
         -------
@@ -172,7 +210,9 @@ class BaseDate:
             The name of the festival or ``None`` if the given date is not
             a Jewish festival.
         """
-        return utils._festival_string(self, israel, hebrew)
+        return utils._festival_string(
+            self, israel, hebrew, include_working_days
+        )
 
     def holiday(self, israel=False, hebrew=False):
         """Return name of Jewish holiday of the date.
@@ -197,22 +237,8 @@ class BaseDate:
         """
         return utils._holiday(self, israel, hebrew)
 
-    def isoweekday(self):
-        """Return the day of the week corresponding to the iso standard.
 
-        Returns
-        -------
-        int
-            An integer representing the day of the week where Monday
-            is 1 and and Sunday is 7.
-        """
-        weekday = self.weekday() 
-        if weekday == 1:
-            return 7
-        return weekday - 1
-
-
-class CalendarDateMixin:
+class CalendarDateMixin(abc.ABC):
     """CalendarDateMixin is a mixin for Hebrew and Gregorian dates.
 
     Parameters
@@ -236,36 +262,19 @@ class CalendarDateMixin:
         self.month = month
         self.day = day
         self._jd = jd
-        self. _error_string = ('''Only a date with a "jd" attribute can
-                              be compared to a {0}'''.format(
-                                                self.__class__.__name__)
-                              )
 
     def __repr__(self):
-        return '{0}({1}, {2}, {3})'.format(self.__class__.__name__,
-                                           self.year,
-                                           self.month,
-                                           self.day)
+        class_name = self.__class__.__name__
+        return f'{class_name}({self.year}, {self.month}, {self.day})'
 
     def __str__(self):
-        return '{0:04d}-{1:02d}-{2:02d}'.format(self.year, self.month, self.day)
+        return f'{self.year:04d}-{self.month:02d}-{self.day:02d}'
 
     def __iter__(self):
         yield self.year
         yield self.month
         yield self.day
 
-    def weekday(self):
-        """Return day of week as an integer.
-
-        Returns
-        -------
-        int
-            An integer representing the day of the week with Sunday as 1
-            through Saturday as 7.
-        """
-        return int(self.jd+.5+1) % 7 + 1
-    
     def tuple(self):
         """Return date as tuple.
 
@@ -311,12 +320,11 @@ class JulianDay(BaseDate):
             self.day = int(day) - .5
         else:
             self.day = int(day) + .5
-        self.jd = self.day
         self._error_string = """Only a date with a "jd" attribute can
-        be compared to a Julian Day instance."""
+            be compared to a Julian Day instance."""
 
     def __repr__(self):
-        return 'JulianDay({0})'.format(self.day)
+        return f'JulianDay({self.day})'
 
     def __str__(self):
         return str(self.day)
@@ -331,10 +339,14 @@ class JulianDay(BaseDate):
         """
         return (int(self.day+.5) + 1) % 7 + 1
 
+    @property
+    def jd(self):
+        return self.day
+
     @staticmethod
     def from_pydate(pydate):
         """Return a `JulianDay` from a python date object.
-        
+
         Parameters
         ----------
         pydate : datetime.date
@@ -401,7 +413,7 @@ class JulianDay(BaseDate):
 
         jd = int(self.day + .5)  # Try to account for half day
         jd -= 347997
-        year = int(jd//365) + 2  ## try that to debug early years
+        year = int(jd//365) + 2  # try that to debug early years
         first_day = utils._elapsed_days(year)
 
         while first_day > jd:
@@ -424,10 +436,13 @@ class JulianDay(BaseDate):
 
         if isinstance(type_, GregorianDate):
             return self.to_greg()
-        elif isinstance(type_, HebrewDate):
+        if isinstance(type_, HebrewDate):
             return self.to_heb()
-        elif isinstance(type_, JulianDay):
+        if isinstance(type_, JulianDay):
             return self
+        raise TypeError(
+            'This method has not been implemented with that type.'
+        )
 
     def to_pydate(self):
         """Convert to a datetime.date object.
@@ -476,10 +491,10 @@ class GregorianDate(BaseDate, CalendarDateMixin):
         adding in date validation specific to Gregorian dates.
         """
         if month < 1 or month > 12:
-            raise ValueError('{0} is an invalid month.'.format(str(month)))
+            raise ValueError(f'{str(month)} is an invalid month.')
         monthlength = self._monthlength(year, month)
         if day < 1 or day > monthlength:
-            raise ValueError('Given month has {0} days.'.format(monthlength))
+            raise ValueError(f'Given month has {monthlength} days.')
         super().__init__(year, month, day, jd)
 
     @property
@@ -508,8 +523,9 @@ class GregorianDate(BaseDate, CalendarDateMixin):
             month += 1
             a = year // 100
             b = 2 - a + a//4
-            self._jd = (int(365.25*year) +
-                        int(30.6001*month) + b + day + 1720994.5)
+            self._jd = (
+                int(365.25*year) + int(30.6001*month) + b + day + 1720994.5
+            )
         return self._jd
 
     @classmethod
@@ -546,11 +562,8 @@ class GregorianDate(BaseDate, CalendarDateMixin):
         """Return True if year of date is a leap year, otherwise False."""
         if year < 0:
             year += 1
-        if(
-            (year % 4 == 0) and not
-            (year % 100 == 0 and year % 400 != 0)
-          ):
-                return True
+        if (year % 4 == 0) and not (year % 100 == 0 and year % 400 != 0):
+            return True
         return False
 
     def is_leap(self):
@@ -567,10 +580,11 @@ class GregorianDate(BaseDate, CalendarDateMixin):
     def _monthlength(cls, year, month):
         if month in [1, 3, 5, 7, 8, 10, 12]:
             return 31
-        elif month != 2:
-            return 30
-        else:
-            return 29 if cls._is_leap(year) else 28
+        if month == 2:
+            if cls._is_leap(year):
+                return 29
+            return 28
+        return 30
 
     def to_jd(self):
         """Convert to a Julian day.
@@ -644,12 +658,12 @@ class HebrewDate(BaseDate, CalendarDateMixin):
         if year < 1:
             raise ValueError('Date supplied is before creation.')
         if month < 1 or month > 13:
-            raise ValueError('{0} is an invalid month.'.format(str(month)))
+            raise ValueError(f'{month} is an invalid month.')
         if (not utils._is_leap(year)) and month == 13:
-            raise ValueError('{0} is not a leap year'.format(year))
+            raise ValueError(f'{year} is not a leap year')
         monthlength = utils._month_length(year, month)
         if day < 1 or day > monthlength:
-            raise ValueError('Given month has {0} days.'.format(monthlength))
+            raise ValueError(f'Given month has {monthlength} days.')
         super().__init__(year, month, day, jd)
 
     @property
@@ -684,7 +698,7 @@ class HebrewDate(BaseDate, CalendarDateMixin):
     @staticmethod
     def from_pydate(pydate):
         """Return a `HebrewDate` from a python date object.
-        
+
         Parameters
         ----------
         pydate : datetime.date
@@ -816,8 +830,7 @@ class HebrewDate(BaseDate, CalendarDateMixin):
         >>> date.hebrew_date_string(True)
         'כ״ה כסלו ה׳תשפ״א'
         """
-        return '{} {} {}'.format(
-            self.hebrew_day(),
-            self.month_name(True),
-            self.hebrew_year(thousands)
-        )
\ No newline at end of file
+        day = self.hebrew_day()
+        month = self.month_name(True)
+        year = self.hebrew_year(thousands)
+        return f'{day} {month} {year}'
