@@ -6,9 +6,8 @@ date.
 """
 from collections import deque
 from numbers import Number
-from functools import lru_cache
 
-from pyluach.dates import GregorianDate, HebrewDate
+from pyluach.dates import HebrewDate
 from pyluach import utils
 from pyluach.gematria import _num_to_str
 from pyluach.utils import _holiday, _fast_day_string, _festival_string
@@ -36,7 +35,7 @@ def fast_day(date, hebrew=False):
     return _fast_day_string(date, hebrew)
 
 
-def festival(date, israel=False, hebrew=False):
+def festival(date, israel=False, hebrew=False, include_working_days=True):
     """Return Jewish festival of given day.
 
     This method will return all major and minor religous
@@ -56,13 +55,18 @@ def festival(date, israel=False, hebrew=False):
       ``True`` if you want the festival name in Hebrew letters. Default
       is ``False``, which returns the name transliterated into English.
 
+    include_working_days : bool, optional
+      ``True`` to include festival days on which melacha (work) is
+      allowed; ie. Pesach Sheni, Chol Hamoed, etc.
+      Default is ``True``.
+
     Returns
     -------
     str or ``None``
       The name of the festival or ``None`` if the given date is not
       a Jewish festival.
     """
-    return _festival_string(date, israel, hebrew)
+    return _festival_string(date, israel, hebrew, include_working_days)
 
 
 def holiday(date, israel=False, hebrew=False):
@@ -126,12 +130,12 @@ class Year:
 
     def __init__(self, year):
         if year < 1:
-            raise ValueError('Year {0} is before creation.'.format(year))
+            raise ValueError(f'Year {year} is before creation.')
         self.year = year
         self.leap = utils._is_leap(year)
 
     def __repr__(self):
-        return 'Year({0})'.format(self.year)
+        return f'Year({self.year})'
 
     def __len__(self):
         return utils._days_in_year(self.year)
@@ -145,8 +149,8 @@ class Year:
         """Add int to year."""
         try:
             return Year(self.year + other)
-        except TypeError:
-            raise TypeError('You can only add a number to a year.')
+        except TypeError as e:
+            raise TypeError('You can only add a number to a year.') from e
 
     def __sub__(self, other):
         """Subtract int or Year from Year.
@@ -156,12 +160,13 @@ class Year:
         """
         if isinstance(other, Year):
             return abs(self.year - other.year)
-        else:
-            try:
-                return Year(self.year - other)
-            except TypeError:
-                raise TypeError('Only an int or another Year object can'
-                                ' be subtracted from a year.')
+        try:
+            return Year(self.year - other)
+        except TypeError as e:
+            raise TypeError(
+                'Only an int or another Year object can'
+                ' be subtracted from a year.'
+            ) from e
 
     def __gt__(self, other):
         if self.year > other.year:
@@ -279,6 +284,7 @@ class Year:
         """
         return _num_to_str(self.year, thousands)
 
+
 class Month:
     """A Month object represents a month of the Hebrew calendar.
 
@@ -308,9 +314,10 @@ class Month:
             transliteration.
     """
 
-    _monthnames = {7: 'Tishrei', 8: 'Cheshvan', 9: 'Kislev', 10: 'Teves',
-                  11: 'Shvat', 13:'Adar Sheni', 1: 'Nissan', 2: 'Iyar',
-                  3: 'Sivan', 4: 'Tamuz', 5: 'Av', 6: 'Elul'}
+    _monthnames = {
+        7: 'Tishrei', 8: 'Cheshvan', 9: 'Kislev', 10: 'Teves',
+        11: 'Shvat', 13: 'Adar Sheni', 1: 'Nissan', 2: 'Iyar',
+        3: 'Sivan', 4: 'Tamuz', 5: 'Av', 6: 'Elul'}
 
     def __init__(self, year, month):
         if year < 1:
@@ -319,13 +326,15 @@ class Month:
         leap = utils._is_leap(self.year)
         yearlength = 13 if leap else 12
         if month < 1 or month > yearlength:
-            raise ValueError('''Month must be between 1 and 12 for a normal
-            year and 13 for a leap year.''')
+            raise ValueError(
+                'Month must be between 1 and 12 for a normal '
+                'year and 13 for a leap year.'
+            )
         self.month = month
         self.name = utils._month_name(self.year, self.month, False)
 
     def __repr__(self):
-        return 'Month({0}, {1})'.format(self.year, self.month)
+        return f'Month({self.year}, {self.month})'
 
     def __len__(self):
         return utils._month_length(self.year, self.month)
@@ -336,9 +345,9 @@ class Month:
 
     def __eq__(self, other):
         if(
-           isinstance(other, Month) and
-           self.year == other.year and
-           self.month == other.month):
+           isinstance(other, Month)
+           and self.year == other.year
+           and self.month == other.month):
             return True
         return False
 
@@ -350,9 +359,8 @@ class Month:
             if other <= leftover_months:
                 return Month(self.year, yearmonths[index + other])
             return Month(self.year + 1, 7).__add__(other - 1 - leftover_months)
-        except (AttributeError, TypeError):
-            raise TypeError('You can only add a number to a year.')
-
+        except (AttributeError, TypeError) as e:
+            raise TypeError('You can only add a number to a month.') from e
 
     def __sub__(self, other):
         if isinstance(other, Number):
@@ -361,16 +369,18 @@ class Month:
             leftover_months = index
             if other <= leftover_months:
                 return Month(self.year, yearmonths[index - other])
-            return Month(self.year - 1,
-                         deque(Year(self.year - 1), maxlen=1).pop()).__sub__(
-                                                    other - 1 - leftover_months
-                                                    )
-                    # Recursive call on the last month of the previous year. 
+            return Month(
+                self.year - 1,
+                deque(Year(self.year - 1), maxlen=1).pop()
+            ).__sub__(other - 1 - leftover_months)
+            # Recursive call on the last month of the previous year.
         try:
             return abs(self._elapsed_months() - other._elapsed_months())
-        except AttributeError:
-            raise TypeError('''You can only subtract a number or a month
-                            object from a month.''')
+        except AttributeError as e:
+            raise TypeError(
+                'You can only subtract a number or a month '
+                'object from a month.'
+            ) from e
 
     def __gt__(self, other):
         if (
@@ -462,10 +472,7 @@ class Month:
         str
             The month and year in Hebrew in the form ``f'{month} {year}'``.
         """
-        return '{} {}'.format(
-            self.month_name(True),
-            _num_to_str(self.year, thousands)
-        )
+        return f'{self.month_name(True)} {_num_to_str(self.year, thousands)}'
 
     def starting_weekday(self):
         """Return first weekday of the month.
@@ -479,7 +486,7 @@ class Month:
         return HebrewDate(self.year, self.month, 1).weekday()
 
     def _elapsed_months(self):
-        '''Return number of months elapsed from beginning of calendar'''
+        """Return number of months elapsed from beginning of calendar"""
         yearmonths = tuple(Year(self.year))
         months_elapsed = (
             utils._elapsed_months(self.year)
@@ -493,8 +500,7 @@ class Month:
         Yields
         ------
         ``HebrewDate``
-            The next Hebrew Date of the year starting the first day of
-            Tishrei through the last day of Ellul.
+            The next Hebrew date of the month.
         """
         for day in self:
             yield HebrewDate(self.year, self.month, day)
@@ -526,7 +532,7 @@ class Month:
 
     def molad_announcement(self):
         """Return the months molad in the announcement form.
-        
+
         Returns a dictionary in the form that the molad is traditionally
         announced. The weekday is adjusted to change at midnight and
         the hour of the day and minutes are given as traditionally announced.
@@ -560,4 +566,4 @@ class Month:
         return {
             'weekday': weekday, 'hour': hour,
             'minutes': minutes, 'parts': parts
-        }
\ No newline at end of file
+        }
